@@ -10,11 +10,14 @@
 # define ETL_NAMESPACE 			etl
 #endif
 
-#ifdef	WIN32
-#define ETL_DIRECTORY_SEPARATOR		'\\'
-#else
-#define ETL_DIRECTORY_SEPARATOR		'/'
-#endif
+#define ETL_DIRECTORY_SEPARATOR0	'/'
+#define ETL_DIRECTORY_SEPARATOR1	'\\'
+
+//#ifdef	WIN32
+//#define ETL_DIRECTORY_SEPARATOR		ETL_DIRECTORY_SEPARATOR1
+//#else
+#define ETL_DIRECTORY_SEPARATOR		ETL_DIRECTORY_SEPARATOR0
+//#endif
 
 #ifndef ETL_FLAG_NONAMESPACE
 # define _ETL					ETL_NAMESPACE
