@@ -4,6 +4,7 @@
 ** $Id$
 **
 ** Copyright (c) 2002 Robert B. Quattlebaum Jr.
+** Copyright (c) 2010 Nikita Kitaev
 **
 ** This package is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License as
@@ -45,11 +46,11 @@ int bspline_basic_test(void)
 	etl::clock timer;
 	double t;
 
-	*BSpline.cpoints().insert(BSpline.cpoints().end())=0;
-	*BSpline.cpoints().insert(BSpline.cpoints().end())=-1;
-	*BSpline.cpoints().insert(BSpline.cpoints().end())=0;
-	*BSpline.cpoints().insert(BSpline.cpoints().end())=1;
-	*BSpline.cpoints().insert(BSpline.cpoints().end())=0;
+	BSpline.cpoints().insert(BSpline.cpoints().end(), 0.0);
+	BSpline.cpoints().insert(BSpline.cpoints().end(), -1.0);
+	BSpline.cpoints().insert(BSpline.cpoints().end(), 0.0);
+	BSpline.cpoints().insert(BSpline.cpoints().end(), 1.0);
+	BSpline.cpoints().insert(BSpline.cpoints().end(), 0.0);
 
 	BSpline.set_m(4);
 	BSpline.reset_knots();
